//
//  GMTCConsumerMapStyleCoordinator.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2022 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

#import "GMTCMarkerStyleOptions.h"
#import "GMTCPolylineStyleOptions.h"

@class GMTCMarkerStyleOptions;
@class GMTCPolylineStyleOptions;

NS_ASSUME_NONNULL_BEGIN

/** Container class for the custom UI options for elements of the GMTCMapView. */
@interface GMTCConsumerMapStyleCoordinator : NSObject

/**
 * Sets the polyline style options for a polyline type. Setting the options to nil will revert the
 * options to the default values. Note that the given polylineStyleOptions is internally copied.
 *
 * @param polylineStyleOptions Polyline style options that are being set.
 * @param polylineType Polyline type that is being set
 */
- (void)setPolylineStyleOptions:(nullable GMTCPolylineStyleOptions *)polylineStyleOptions
                   polylineType:(GMTCPolylineType)polylineType;

/**
 * Sets the marker style options for a marker type. Setting the options to nil will revert the
 * options to the default values. Note that the given markerStyleOptions is internally copied.
 *
 * @param markerStyleOptions Marker style options that are being set.
 * @param markerType Marker type that is being set
 */
- (void)setMarkerStyleOptions:(nullable GMTCMarkerStyleOptions *)markerStyleOptions
                   markerType:(GMTCCustomizableMarkerType)markerType;

/**
 * Retrieves polyline style options for a type of polyline.
 *
 * @param polylineType Retrieves polyline style options for this type.
 */
- (GMTCPolylineStyleOptions *)polylineStyleOptionsForType:(GMTCPolylineType)polylineType;

/**
 * Retrieves marker style options for a marker type.
 *
 * @param markerType Retrieves marker stlye options for this type.
 */
- (GMTCMarkerStyleOptions *)markerStyleOptionsForType:(GMTCCustomizableMarkerType)markerType;

@end

NS_ASSUME_NONNULL_END
