//
//  GMTCMapViewSession.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2022 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

@class GMTCMapView;
@protocol GMTCMapViewSession;

NS_ASSUME_NONNULL_BEGIN

/**
 * \defgroup GMTCMapViewSessionState GMTCMapViewSessionState
 * @{
 */

/** Describes the activity status of a map view session. */
typedef NS_ENUM(NSUInteger, GMTCMapViewSessionState) {
  /** The map view session is not yet added to a map view. */
  GMTCMapViewSessionStateInactive,

  /** The map view session is added to a map view. */
  GMTCMapViewSessionStateActive,
};

/**@}*/

@protocol GMTCMapViewSessionDelegate <NSObject>
@optional
/** A callback triggers after the session state has been updated. */
- (void)mapViewSession:(id<GMTCMapViewSession>)session
        didUpdateState:(GMTCMapViewSessionState)state;
@end

@protocol GMTCMapViewSession <NSObject>
@optional
/**
 * Returns the current session state. The possible state can be referenced from
 * GMTCMapViewSessionState.
 */
@property(nonatomic, nullable, weak) __kindof id<GMTCMapViewSessionDelegate> delegate;

@required
/**
 * Returns the current session state. The possible state can be referenced from
 * GMTCMapViewSessionState.
 */
@property(nonatomic, readonly) GMTCMapViewSessionState state;

/** Returns the host map view of the current session. */
@property(nonatomic, nullable, weak, readonly) GMTCMapView *hostMapView;

/** Called by a GMTCMapView instance when the session has been added to it. */
- (void)didAddToMapView:(GMTCMapView *)mapView;

/** Called by a GMTCMapView instance when the session has been removed from it. */
- (void)didRemoveFromMapView:(GMTCMapView *)mapView;

@end

NS_ASSUME_NONNULL_END
