//
//  GMTCServices.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2022 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

@class GMTCTripService;
@protocol GMTCAuthorization;

NS_ASSUME_NONNULL_BEGIN

/** Service class for the Google Consumer Ridesharing SDK for iOS. */
@interface GMTCServices : NSObject

/** Return an instance of the GMTCTripService. */
@property(nonatomic, readonly) GMTCTripService *tripService;

/**
 * Main Rodesharing SDK init method. Should be called before any other method.
 *
 * @param accessTokenProvider  An implementation of GMTCAuthorization, which can provide a valid
 * access token.
 * @param providerID   An ID of the Google Cloud Project (e.g. sample-consumer-project).
 */
+ (void)setAccessTokenProvider:(id<GMTCAuthorization>)accessTokenProvider
                    providerID:(NSString *)providerID;

/**
 * Provides the shared instance of GMTCServices for the Google Ridesharing SDK for iOS. Ridesharing
 * classes will hold this instance to provide their connection to Google.
 *
 * This method will throw an exception if setAccessTokenProvider: has not been called.
 */
+ (instancetype)sharedServices;

/**
 * Returns the version for this release of the Google Ridesharing SDK for iOS. For example, "0.4.4".
 * The version number is in the SDK's resource bundle.
 */
+ (NSString *)SDKVersion;

/**
 * Returns the long formatted version of the string. It includes the version string and bundle
 * version in format "<SHORT VERSION> (<BUNDLE VERSION>)". For example, "0.4.4 (234.2)".
 */
+ (NSString *)SDKLongVersion;

/**
 * Enables reporting of abnormal SDK terminations such as when the app crashes while the SDK is
 * still running. This allows Google to improve SDK stability when applicable. The default is @c YES
 * and value must be updated before the `sharedServices` is called.
 *
 * This property must be set from the main thread.
 */
+ (void)setAbnormalTerminationReportingEnabled:(BOOL)abnormalTerminationReportingEnabled;

@end

NS_ASSUME_NONNULL_END
