//
//  GMTCTripModelOptions.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2022 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//
#import "GMTSRequestOptions.h"

@class GMTSRequestHeader;

NS_ASSUME_NONNULL_BEGIN

/** Object that for configuring the @c GMTCTripModel. */
@interface GMTCTripModelOptions : GMTSRequestOptions <NSMutableCopying>

/** Returns the current refresh time interval between the repeated trip info polling from server. */
@property(nonatomic, readonly) NSTimeInterval autoRefreshTimeInterval;

/** Returns the request header that will be appended to each trip info polling call. */
@property(nonatomic, readonly, nullable) GMTSRequestHeader *tripRequestHeader;

/**
 * Initializes the instance.
 *
 * @param autoRefreshTimeInterval A refresh time inverval between the repeated trip info polling.
 * @param tripRequestHeader A trip request header that will be appended to each trip info polling
 * call.
 */
- (instancetype)initWithAutoRefreshTimeInterval:(NSTimeInterval)autoRefreshTimeInterval
                              tripRequestHeader:(nullable GMTSRequestHeader *)tripRequestHeader
    NS_DESIGNATED_INITIALIZER;

/**
 * Initializes the instance. Calling this is equivalent to calling
 * `initWithAutoRefreshTimeInterval:0.0 tripRequestHeader:nil`.
 */
- (instancetype)init;

@end

/** Mutable version of @c GMTCTripModelOptions. */
@interface GMTCMutableTripModelOptions : GMTCTripModelOptions

/**
 * Sets or gets the current refresh time interval between the repeated trip info polling from
 * server.
 */
@property(nonatomic) NSTimeInterval autoRefreshTimeInterval;

/** Sets or gets the request header that will be appended to each trip info polling call. */
@property(nonatomic, copy, nullable) GMTSRequestHeader *tripRequestHeader;

/**
 * Creates and returns an instance of @c GMTCMutableTripModelOptions based on the given instance of
 * @c GMTCTripModelOptions.
 *
 * @param options The original instance of @c GMTCTripModelOptions, based on where the mutable data
 * will be constructed.
 */
+ (instancetype)mutableTripModelOptionsWithOptions:(nullable GMTCTripModelOptions *)options;
@end

NS_ASSUME_NONNULL_END
