//
//  GMTCTripRequest.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2022 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import "GMTSRequest.h"

NS_ASSUME_NONNULL_BEGIN

/** A request object for specifying parameters to get an active trip. */
@interface GMTCTripRequest : GMTSRequest <NSCopying, NSMutableCopying>

/** Name of the target trip. The value will be an empty string(@"") if set as nil. */
@property(nonatomic, copy, readonly, null_resettable) NSString *tripName;

/** Refresh time interval of the trip request. */
@property(nonatomic, readonly) NSTimeInterval autoRefreshTimeInterval;

/**
 * Initializes the object.
 *
 * @param requestHeader  The header object of the request.
 * @param tripName  Name of trip, if set as nil, the property `tripName` getter will return @"".
 * @param autoRefreshTimeInterval  The refresh time interval of the trip request.
 */
- (instancetype)initWithRequestHeader:(nullable GMTSRequestHeader *)requestHeader
                             tripName:(nullable NSString *)tripName
              autoRefreshTimeInterval:(NSTimeInterval)autoRefreshTimeInterval
    NS_DESIGNATED_INITIALIZER;

/** Use initWithRequestHeader:providerId:tripId:autoRefreshTimeInterval: instead. */
- (instancetype)init NS_UNAVAILABLE;

@end

/** Mutable version of GMTCTripRequest. */
@interface GMTCMutableTripRequest : GMTCTripRequest

/** Header of the request. */
@property(nonatomic, copy, nullable) GMTSRequestHeader *requestHeader;

/** ID of the target trip. The value will be an empty string(@"") if set as nil. */
@property(nonatomic, copy, null_resettable) NSString *tripName;

/** Refresh time interval of the trip request. */
@property(nonatomic) NSTimeInterval autoRefreshTimeInterval;

/** Initializes the object. */
- (instancetype)init;

@end

NS_ASSUME_NONNULL_END
