//
//  GMTCTripService.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2022 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <Foundation/Foundation.h>

@class GMTCTripModel;

NS_ASSUME_NONNULL_BEGIN

/** Provides methods for accessing trip session(s). */
@interface GMTCTripService : NSObject

/**
 * Creates and returns an instance of GMTCTripModel by the given trip name.
 * If a trip session instance has already been created for the given trip name, then that instance
 * will be returned.
 * The instance of the TripModelcreated or retrieved can be configured via the `sessionOptions`
 * of GMTCTripModel. Usually this `sessionOptions` property can be used to adjust the refresh time
 * interval between the repeated trip info polling. see the comment in the class
 * GMTCTripModelOptions for more details.
 *
 * @param tripName The trip name for identifying a trip.
 */
- (nullable GMTCTripModel *)tripModelForTripName:(NSString *)tripName;

/**
 * Returns whether there has been a trip session created by the GMTCTripService.
 *
 * @param tripName The trip name for identifying a trip.
 */
- (BOOL)hasTripModelForTripName:(NSString *)tripName;

/** Returns all the trip session objects created by this trip service. */
- (NSArray<GMTCTripModel *> *)allTripModels;

/**
 * Returns all the trip session objects created by this trip service which are actively running.
 */
- (NSArray<GMTCTripModel *> *)activeTripModels;

/** This class has no public initializers. */
- (null_unspecified instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
