//
//  GMTSLatLng.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import <CoreLocation/CoreLocation.h>

#import "GMTSImmutableData.h"

@class GMTSLatLng;

/**
 * Delta threshold allowed between objects for @c AlmostEqual to return `YES`.
 * This value is `1e-7`.
 */
FOUNDATION_EXPORT const double GMTSLatLngDegreeAlmostEqualTolerance;

NS_ASSUME_NONNULL_BEGIN

/**
 * Object representing the latitude and longitude.
 */
@interface GMTSLatLng : GMTSImmutableData

/**
 * Latitude associated with the object.
 */
@property(nonatomic, readonly) double latitude;

/**
 * Longitude associated with the object.
 */
@property(nonatomic, readonly) double longitude;

/**
 * Creates and returns an initialized GMTSLatLng from given CLLocationCoordinate2D.
 */
+ (instancetype)latLngFromCoordinate:(CLLocationCoordinate2D)coordinate;

/**
 * Initializes the object with the specified `latitude` and `longitude'.
 */
- (instancetype)initWithLatitude:(double)latitude longitude:(double)longitude;

/**
 *  @remark Use {@code initWithLatitude:longitude:}.
 */
- (instancetype)init NS_UNAVAILABLE;

/**
 * Creates and returns an CLLocationCoordinate2D from current GMTSLatLng.
 */
- (CLLocationCoordinate2D)coordinate;

/**
 * Gets the lateral distance from the given latlng to the current location.
 */
- (CLLocationDistance)distanceFromLocation:(GMTSLatLng *)latlng;

/**
 * Indicates if the receiver is almost equal to another given @c GMTSLatLng object based on the
 * constant, @c GMTSLatLngDegreeAlmostEqualTolerance.
 */
- (BOOL)isAlmostEqual:(nullable GMTSLatLng *)latlng;

@end

NS_ASSUME_NONNULL_END
