//
//  GMTSSpeedReadingSpan.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import "GMTSImmutableData.h"

NS_ASSUME_NONNULL_BEGIN

/**
 * \defgroup GMTSSpeedType GMTSSpeedType
 * @{
 */

/**
 * Enum representing supported speed types on a path.
 */
typedef NS_ENUM(NSUInteger, GMTSSpeedType) {
  GMTSSpeedTypeNoData,
  GMTSSpeedTypeNormal,
  GMTSSpeedTypeSlow,
  GMTSSpeedTypeTrafficJam,
};

/**@}*/

/**
 * A data object that holds the traffic conditions for a contiguous segment of a polyline.
 */
@interface GMTSSpeedReadingSpan : GMTSImmutableData

/** The traffic conditions for this segment. */
@property(nonatomic, readonly) GMTSSpeedType speedType;

/**
 * The starting index (inclusive) for this interval of the routePath array of the owning
 * GMTSTrafficData object.
 */
@property(nonatomic, readonly) int32_t startIndex;

/**
 * The ending index for this interval of the routePath array of the owning GMTSTrafficData object.
 * The index is exclusive; the implied points on the polyline between the previous index and this
 * index are included in the interval, but the point specified by the index is not included.
 */
@property(nonatomic, readonly) int32_t endIndex;

/**
 * Initializes the GMTSSpeedReadingSpan object by passing the speed interval attributes.
 *
 * @param speedType The speed type for a segment of a polyline path.
 * @param startIndex The start index for a segment of the routePath array of the owning
 * GMTSTrafficData object.
 * @param endIndex The end index for a segment of the routePath array of the owning GMTSTrafficData
 * object.
 */
- (instancetype)initWithSpeedType:(GMTSSpeedType)speedType
                       startIndex:(int32_t)startIndex
                         endIndex:(int32_t)endIndex NS_DESIGNATED_INITIALIZER;

/**
 * Use @c initWithSpeedType:startIndex:endIndex instead.
 */
- (null_unspecified instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
