//
//  GMTSTerminalLocation.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import "GMTSImmutableData.h"

@class GMTSLatLng;

NS_ASSUME_NONNULL_BEGIN

/**
 * Object representing information that identifies a terminal location.
 */
@interface GMTSTerminalLocation : GMTSImmutableData

/**
 * The point location of the terminal.
 */
@property(nonatomic, readonly, copy, nullable) GMTSLatLng *point;

/**
 * Human-readable name of the terminal location.
 */
@property(nonatomic, readonly, copy, nullable) NSString *terminalLocationLabel;

/**
 * A longer description of the terminal location, which may include how to get to the location.
 */
@property(nonatomic, readonly, copy, nullable) NSString *terminalLocationDescription;

/**
 * The Place ID of the terminal point.
 * Refer to https://developers.google.com/places/web-service/place-id for more detail.
 */
@property(nonatomic, readonly, copy, nullable) NSString *placeID;

/**
 * A generated ID if the place ID is not available. The ID is nil if there is already a valid place
 * ID.
 */
@property(nonatomic, readonly, copy, nullable) NSString *generatedID;

/**
 * Indicates the access point ID of the current terminal location for the associated trip.
 * If an associated trip does not exist, the value is nil. Requires an associated trip.
 */
@property(nonatomic, readonly, copy, nullable) NSString *accessPointID;

/**
 * Initializes an instance of GMTSTerminalLocation.
 *
 * @param point  The point location of the terminal.
 * @param terminalLocationLabel  Human-readable name of the terminal location.
 * @param terminalLocationDescription  A longer description of the terminal location, which may
 *                                     include how to get to the location.
 * @param placeID  The Place ID of the terminal point.
 * @param generatedID  A generated ID if the place ID is not available.
 * @param accessPointID  An access point ID of the current terminal location from the associated
 *                       trip.
 */
- (instancetype)initWithPoint:(nullable GMTSLatLng *)point
                        label:(nullable NSString *)terminalLocationLabel
                  description:(nullable NSString *)terminalLocationDescription
                      placeID:(nullable NSString *)placeID
                  generatedID:(nullable NSString *)generatedID
                accessPointID:(nullable NSString *)accessPointID NS_DESIGNATED_INITIALIZER;

/**
 * Use {@code initWithPoint:label:description:placeID:generatedID:accessPointID:}
 * instead.
 */
- (instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
