//
//  GMTSTrafficData.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import "GMTSImmutableData.h"

@class GMTSLatLng;
@class GMTSSpeedReadingSpan;

NS_ASSUME_NONNULL_BEGIN

/**
 * An object that holds the traffic data for a stretch of road.
 */
@interface GMTSTrafficData : GMTSImmutableData

/**
 * The array of LatLngs that make the polyline representing the path for a stretch of data. Note
 * that this path may vary subtly from the path for the route. For example, there might be
 * additional points needed where speed types change.
 */
@property(nonatomic, readonly) NSArray<GMTSLatLng *> *routePath;

/**
 * The array of GMTSSpeedReadingSpans objects for a segment of the polyline path.
 */
@property(nonatomic, readonly) NSArray<GMTSSpeedReadingSpan *> *speedReadingSpans;

/**
 * Initializes the object by passing the traffic data attributes.
 *
 * @param routePath The list of LatLngs that make up the route.
 * @param speedReadingSpans The array of GMTSSpeedReadingSpans objects for the route.
 */
- (instancetype)initWithRoutePath:(NSArray<GMTSLatLng *> *)routePath
                speedReadingSpans:(NSArray<GMTSSpeedReadingSpan *> *)speedReadingSpans
    NS_DESIGNATED_INITIALIZER;

/**
 * Use @c initWithRoutePath:speedReadingSpans instead.
 */
- (instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
