//
//  GMTSVehicleType.h
//  Google Ridesharing SDK for iOS
//
//  Copyright 2021 Google LLC
//
//  Usage of this SDK is subject to the Google Maps/Google Earth APIs Terms of
//  Service: https://cloud.google.com/maps-platform/terms
//

#import "GMTSImmutableData.h"

NS_ASSUME_NONNULL_BEGIN

/**
 * \defgroup GMTSVehicleTypeCategory GMTSVehicleTypeCategory
 * @{
 */

/**
 * Enum that defines all vehicle types.
 */
typedef NS_ENUM(NSUInteger, GMTSVehicleTypeCategory) {
  GMTSVehicleTypeCategoryUnknown,
  GMTSVehicleTypeCategoryAuto,
  GMTSVehicleTypeCategoryTaxi,
  GMTSVehicleTypeCategoryTruck,
  GMTSVehicleTypeCategoryTwoWheeler,
};

/**@}*/

/**
 * Data object containing information about the type of the vehicle.
 */
@interface GMTSVehicleType : GMTSImmutableData

/**
 * The vehicle type category, see GMTSVehicleTypeCategory for all the options.
 */
@property(nonatomic, readonly) GMTSVehicleTypeCategory category;

- (instancetype)initWithCategory:(GMTSVehicleTypeCategory)category NS_DESIGNATED_INITIALIZER;

- (instancetype)init NS_UNAVAILABLE;

@end

NS_ASSUME_NONNULL_END
